{% load i18n %}
{% load crispy_forms_tags %}
<div class="container">
    <div id="formset">
        {{ formset.management_form }}
        {% for form in formset %}
        <div id="form-0" class="formset pt-2">
            <div class="row">
                {{form|crispy}}
            </div>
            <div id="formset2">
                {{ formset2.management_form }}
                {% for form2 in formset2 %}
                    <div id="form2-0" class="formset2 pt-2">
                        <div class="row">
                            {{form2|crispy}}
                        </div>
                    </div>
                {% endfor %}
                <div id="empty-form2" class="d-none">
                    <div class="row">
                        {{formset2.empty_form|crispy}}
                    </div>
                </div>
            </div>
            <div class="d-flex justify-content-between my-3">
                <button class="btn-clear" onclick="addFormsetCKE()" type="button"><i class="fa-solid fa-plus"></i> {% trans "Add" %}</button>
                <button class="btn-clear remove-formset" onclick="clearFormsetCKE()" type="button"><i class="fa-solid fa-minus"></i> {% trans "Remove" %}</button>
            </div>
        </div>
        {% endfor %}
        <div id="empty-form" class="d-none">
            <div class="row">
                {{formset.empty_form|crispy}}
            </div>
        </div>
    </div>
    <div class="d-flex justify-content-between my-3">
        <button class="btn-clear" onclick="addFormsetCKE2()" type="button"><i class="fa-solid fa-plus"></i> {% trans "Add" %}</button>
        <button class="btn-clear remove-formset" onclick="clearFormsetCKE2()" type="button"><i class="fa-solid fa-minus"></i> {% trans "Remove" %}</button>
    </div> 
</div>
<p class="response-footer text-link fw-bold oxanium"></p>
<input type="hidden" name="form-id" value="faq-form">